Learn R Programming

pwSEM (version 1.0.0)

sim_tetrads: sim_tetrads: Simulated data to be used with the vanishing.tetrads function Data generated using this directed acyclic graph, with L being latent: L->X1, L->X2, L->X3->X4

Description

sim_tetrads: Simulated data to be used with the vanishing.tetrads function Data generated using this directed acyclic graph, with L being latent: L->X1, L->X2, L->X3->X4

Usage

sim_tetrads

Arguments

Format

'sim_tetrads'

A data set with 500 rows and 4 columns

X1

A Gaussian variable

X2

A Gaussian variable

X3

A Gaussian variable

X4

A Gaussian variable