The maximum likelihood chi-square statistic that
is commonly calculated in structural equations modelling only
asymptotically follows a theoretical chi-squared distribution;
with small sample sizes it can deviate enough from the theoretical
distribution to make it problematic.This function estimates the
empirical probability distribution of the Maximum Likelihood
Chi-Square statistic, given a fixed sample size and degrees of
freedom, and outputs the estimated null probability given this
sample size and degrees of freedom.